<?php

if ( ! class_exists('Kopa_Page_Builder') && ! is_admin() ) {
    return;
}

add_action('init', 'verado_lite_page_builder_init');

add_filter('kopa_page_builder_get_layouts', 'verado_lite_page_builder_set_layouts');
add_filter('kopa_page_builder_get_areas', 'verado_lite_page_builder_set_areas');
add_filter('kopa_page_builder_get_section_fields', 'verado_lite_page_builder_set_section_fields');

add_filter('body_class', 'verado_lite_page_builder_set_body_class');
add_action('wp_enqueue_scripts', 'verado_lite_page_builder_enqueue_script', 20);

add_filter('kopa_page_builder_get_customize_fields', 'verado_lite_page_builder_set_customize_fields');

function verado_lite_page_builder_set_customize_fields($fields){

    $fields['background']['title'] =  __('Background', 'verado-lite');
    $fields['background']['params'] = array(
        'background-image' => array(
            'type' => 'image',
            'title' => __('Background image', 'verado-lite'),
            'default' => '',
        ),
        'background-color' => array(
            'type' => 'color',
            'title' => __('Background color', 'verado-lite'),
            'default' => '',
        )
    );

    $fields['padding']['title'] =  __('Padding', 'verado-lite');
    $fields['padding']['params'] = array(
        'top' => array(
            'type' => 'number',
            'title' => __('Top', 'verado-lite'),
            'default' => '',
            'affix' => 'px',
        ),
        'bottom' => array(
            'type' => 'number',
            'title' => __('Bottom', 'verado-lite'),
            'default' => '',
            'affix' => 'px',
        ),
        'left' => array(
            'type' => 'number',
            'title' => __('Left', 'verado-lite'),
            'default' => '',
            'affix' => 'px',
        ),
        'right' => array(
            'type' => 'number',
            'title' => __('Right', 'verado-lite'),
            'default' => '',
            'affix' => 'px',
        ),
    );

    $fields['custom']['title'] =  __('Custom CSS', 'verado-lite');
    $fields['custom']['params'] = array(
        'css' => array(
            'type' => 'textarea',
            'title' => __('CSS code', 'verado-lite'),
            'default' => '',
            'rows' => 10,
            'class' => 'kpb-ui-textarea-guide-line',
            'help' => __('Example: <code>ID a {color: red; }</code> <br/> ID: The ID of this widget.', 'verado-lite'),
        ),
    );

    return $fields;
}

function verado_lite_page_builder_init(){
    add_filter('kopa_get_template_part', 'verado_lite_page_builder_get_template_part');
}

function verado_lite_page_builder_set_areas($areas){

    $areas['area-1'] = __( 'Area 1', 'verado-lite' );
    $areas['area-2-1'] = __( 'Area 2.1', 'verado-lite' );
    $areas['area-2-2'] = __( 'Area 2.2', 'verado-lite' );

    $areas['area-2'] = __( 'Area 2', 'verado-lite' );
    return $areas;
}

function verado_lite_page_builder_set_layouts($layouts){

    $layouts['disable'] = array(
        'title' => __('-- Disable --', 'verado-lite')
    );

    $layouts['front-page'] = array(
        'title' => __('Front page', 'verado-lite'),
        'preview' => get_template_directory_uri() . '/images/layouts/front-page.png',
        'customize' => array(),
        'section' => array(
            'row-1' => array(
                'title' => __('Page elements', 'verado-lite'),
                'grid' => array(12),
                'description' => '',
                'customize' => array(),
                'area' => array('area-1')
            ),
        )
    );

    $layouts['shop-page'] = array(
        'title' => __('Shop page', 'verado-lite'),
        'preview' => get_template_directory_uri() . '/images/layouts/front-page.png',
        'customize' => array(),
        'section' => array(
            'row-1' => array(
                'title' => __('Page elements', 'verado-lite'),
                'grid' => array(12),
                'description' => '',
                'customize' => array(),
                'area' => array('area-1')
            ),
        )
    );

    $layouts['static-page'] = array(
        'title' => __('Static page', 'verado-lite'),
        'preview' => get_template_directory_uri() . '/images/layouts/static-page.png',
        'customize' => array(),
        'section' => array(
            'row-1' => array(
                'title' => __('Row 1', 'verado-lite'),
                'grid' => array(9,3),
                'description' => '',
                'customize' => array(),
                'area' => array(
                    'area-2-1',
                    'area-2-2',
                )
            )
        )
    );

    return $layouts;
}

function verado_lite_page_builder_set_section_fields($fields){
    $fields = array();
    return $fields;
}

function verado_lite_page_builder_get_template_part($template){
    if(is_page()){
        global $post;
        $verado_current_layout = Kopa_Page_Builder::get_current_layout($post->ID);
        if ( empty($verado_current_layout) ) {
            $verado_current_layout = 'disable';
        }

        if( $verado_current_layout != 'disable' ){
            $template = "pages/{$verado_current_layout}";
        }
    }
    return $template;
}

function verado_lite_page_builder_set_body_class($classes){
    if(is_page()){
        global $post;
        $verado_current_layout = Kopa_Page_Builder::get_current_layout($post->ID);
        if ( 'front-page' == $verado_current_layout || 'shop-page' == $verado_current_layout ) {
            array_push($classes, 'kopa-home');
        }

        if( $page_data = Kopa_Page_Builder::get_current_layout_data($post->ID) ){
            if( ! isset($page_data['row-1']['area-2-2']) ) {
                array_push($classes, 'kopa-fullwidth-page');
            }
        }
    }
    return $classes;
}

function verado_lite_page_builder_enqueue_script(){
    if(is_page()){
        global $post;
        $page_data = Kopa_Page_Builder::get_current_layout_data($post->ID);

        $style = '';

        if(!empty($page_data)){
            foreach($page_data as $section_id => $section){
                if(!empty($section)){
                    foreach ($section as $area_id => $area) {
                        if(!empty($area)){
                            foreach ($area as $widget_id => $widget) {
                                if($widget_data = get_post_meta($post->ID, $widget_id, true)){
                                    foreach(array('padding') as $box_mode){
                                        foreach(array('top', 'bottom', 'left', 'right') as $position){
                                            if(isset($widget_data['customize'][$box_mode][$position])){
                                                if(trim($widget_data['customize'][$box_mode][$position]) != ''){
                                                    $style .= sprintf('#%s { %s-%s: %s%s; }', $widget_id, $box_mode, $position, $widget_data['customize'][$box_mode][$position], 'px');
                                                }
                                            }
                                        }
                                    }

                                    if(isset($widget_data['customize']['background']['background-image'])){
                                        if(trim($widget_data['customize']['background']['background-image']) != ''){
                                            $style .= sprintf('#%s .widget-content { background: url("%s") top center no-repeat; }', $widget_id, $widget_data['customize']['background']['background-image']);
                                        }
                                    }

                                    if(isset($widget_data['customize']['background']['background-color'])){
                                        if(trim($widget_data['customize']['background']['background-color']) != ''){
                                            $style .= sprintf('#%s, #%s .widget-content { background-color: %s; }', $widget_id, $widget_id, $widget_data['customize']['background']['background-color']);
                                        }
                                    }

                                    if(isset($widget_data['customize']['custom']['css']) && !empty($widget_data['customize']['custom']['css'])){
                                        $style .= str_replace('ID', "#{$widget_id}", $widget_data['customize']['custom']['css']);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        if(!empty($style)){
            wp_add_inline_style(KOPA_PREFIX . 'style', $style);
        }
    }
}

function verado_lite_dynamic_area($post_id, $data){
    if($data){

        foreach($data as $widget_id => $widget){

            if($widget_data = get_post_meta($post_id, $widget_id, true)){
                $class_name = $widget['class_name'];
                if(class_exists($class_name)){

                    $instance = $widget_data['widget'];

                    $obj = new $class_name;

                    $obj->id = $widget_id;
                    $obj->number = rand(0, 9999);

                    $widget_wrap = array(
                        'before_widget' => sprintf('<div id="%1$s" class="widget %2$s">', $obj->id, $obj->widget_options['classname']),
                        'after_widget' => '</div>',
                        'before_title' => '<h3 class="widget-title">',
                        'after_title' => '</h3>'
                    );
                    $obj->widget($widget_wrap, $instance);
                }

            }

        }

    }
}

