<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Kopa_Widget_List_Post_Carousel extends Kopa_Widget
{
    public $kpb_group = 'Sliders';

	function __construct()
	{
		$this->widget_cssclass    = 'kopa-top-slide kopa-top-slide-2';
		$this->widget_description = __( 'Show list posts with carousel effect for home page', 'verado-lite' );
		$this->widget_id          = 'kopa-top-slidewidget';
		$this->widget_name        = __( '(Kopa) Slide', 'verado-lite' );

		$setting = verado_lite_post_widget_setting('', 15);

        if ( isset($setting['title']) ){
            unset($setting['title']);
        }

        $setting_more = array(
            'slider_speed' => array(
                'type'    => 'number',
                'std'     => '500',
                'label'   => __( 'Slide Speed', 'verado-lite' ),
                'min'     => '1',
            ),
            'is_autoplay' => array(
                'type' => 'checkbox',
                'label' => __( 'Auto play slider', 'verado-lite' ),
                'std' => 0,
            ),
            'addition_title' => array(
                'type' => 'text',
                'label' => __( 'Addition title', 'verado-lite' ),
                'std' => '',
            ),
            'addition_text' => array(
                'type' => 'textarea',
                'label' => __( 'Addition text', 'verado-lite' ),
                'std' => '',
                'row' => 3
            ),
        );
		$this->settings = array_merge($setting, $setting_more);
		parent::__construct();
	}

	function widget($args, $instance){
		ob_start();
		extract($args);

        $instance = wp_parse_args((array) $instance, verado_lite_get_widget_default($this->settings));
        $slider_auto_play = $instance['is_autoplay'];
        $slider_speed = intval($instance['slider_speed']);

		$new_query = verado_lite_build_query($instance);
		$posts = new WP_Query($new_query);

        echo $before_widget;
       ?>
            <?php if ( $posts->have_posts() ) { ?>

                <div class="slide-wrapper-outer">
                    <div class="slide-wrapper-inner loading">
                        <div class="slide owl-carousel" data-speed="<?php echo esc_attr($slider_speed); ?>" data-auto="<?php echo esc_attr($slider_auto_play); ?>">
                            <?php while ( $posts->have_posts() ):
                                $posts->the_post();
                                $post_id = get_the_ID();
                                $post_title = get_the_title();
                                if ( empty($post_title) ) {
                                    $post_title = __('No Title', 'verado-lite');
                                }
                                ?>

                                <div class="item">
                                    <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr($post_title); ?>">
                                        <?php verado_lite_the_post_thumbnail($post_id, 'widget-kopa-slide', $post_title, 'lazyOwl');?>
                                        <div class="mask"></div>
                                    </a>
                                    <div class="intro top-slide-intro">
                                        <h6 class="title"><a href="<?php the_permalink(); ?>" title="<?php echo esc_attr($post_title); ?>"><?php echo esc_html($post_title); ?></a></h6>
                                        <?php the_excerpt(); ?>
                                        <div class="view-more">
                                            <span class="bg-1"></span>
                                            <span class="bg-2"></span>
                                            <span class="bg-3"></span>
                                            <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr($post_title); ?>" class="link"><?php esc_html_e('read more', 'verado-lite'); ?></a>
                                        </div>
                                    </div>
                                </div>

                            <?php endwhile; wp_reset_postdata(); ?>
                        </div>

                        <ul class="control-top-slide">
                            <?php while ( $posts->have_posts() ):
                                $posts->the_post();
                                ?>
                                <li>
                                    <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php echo verado_lite_the_post_thumbnail(get_the_ID(), 'widget-kopa-slide-thumb', get_the_title()); ?></a>
                                </li>
                            <?php endwhile; wp_reset_postdata(); ?>
                        </ul>
                        <!-- .control-top-slide -->
                    </div>
                </div>

                <?php
                    if ( ! empty($instance['addition_title']) || ! empty($instance['addition_text']) ) :
                ?>
                    <div class="purchase-box">
                        <div class="wrapper">
                            <?php if ( ! empty($instance['addition_title']) ) : ?>
                                <p class="h5"><?php echo esc_html($instance['addition_title']); ?></p>
                            <?php endif; ?>
                            <?php if ( ! empty($instance['addition_text']) ) : ?>
                                <p><?php echo esc_textarea($instance['addition_text']); ?></p>
                            <?php endif; ?>
                        </div>
                    </div>
                    <!-- .purchase-box -->
                <?php endif; ?>

            <?php } ?>

        <?php
        echo $after_widget;
		$content = ob_get_clean();
        echo $content;
	}
}

