<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Kopa_Widget_Article_List extends Kopa_Widget
{
    public $kpb_group = 'post';

	function __construct()
	{
		$this->widget_cssclass    = 'kopa-article-list-widget';
		$this->widget_description = __( 'Show list posts', 'verado-lite' );
		$this->widget_id          = 'kopa-article-list-widget';
		$this->widget_name        = __( '(Kopa) List Posts', 'verado-lite' );

		$setting = verado_lite_post_widget_setting(__('Latest news', 'verado-lite'), 55, 3);
        $setting['show_date'] = array(
            'type' => 'checkbox',
            'label' => __('Show date', 'verado-lite'),
            'std' => '1'
        );
        $setting['show_category'] = array(
            'type' => 'checkbox',
            'label' => __('Show category', 'verado-lite'),
            'std' => '1'
        );
        $setting['show_comment'] = array(
            'type' => 'checkbox',
            'label' => __('Show comment', 'verado-lite'),
            'std' => '1'
        );
        $setting['show_exceprt'] = array(
            'type' => 'checkbox',
            'label' => __('Show excerpt', 'verado-lite'),
            'std' => '1'
        );

		$this->settings = $setting;
		parent::__construct();
	}

	function widget($args, $instance){
		ob_start();
		extract($args);
        wp_parse_args((array)$instance, verado_lite_get_widget_default($this->settings));
        extract($instance);
        $title = apply_filters( 'widget_title', $instance['title'] );

		$new_query = verado_lite_build_query($instance);
		$posts = new WP_Query($new_query);

		echo $before_widget;

        ?>

            <div class="container">
                <?php if ( ! empty($title) ) : ?>
                    <div class="widget-top">
                        <div class="widget-title title-s3">
                            <h3><?php echo esc_html($title); ?></h3>
                            <span class="red-bg"></span>
                        </div>
                        <p class="t-des"><?php echo esc_textarea($description); ?></p>
                    </div>
                <?php endif; ?>

                <?php if ( $posts->have_posts() ) : ?>

                    <div class="widget-content entry-box row">
                        <?php while ( $posts->have_posts() ) :
                            $posts->the_post();
                            $post_title = get_the_title();
                            $post_excerpt = get_the_excerpt();
                            if ( empty($post_title) ) {
                                $post_title = __('No title', 'verado-lite');
                            }
                            ?>

                        <div class="col-md-4 col-sm-4 col-xs-12">
                            <div class="entry-item">
                                <?php if ( has_post_thumbnail() ) : ?>
                                    <div class="entry-thumb">
                                        <a href="<?php the_permalink();?>" title="<?php echo esc_attr($post_title); ?>"><?php verado_lite_the_post_thumbnail(get_the_ID(), 'post-list-thumb', get_the_title()); ?></a>
                                    </div>
                                <?php endif; ?>
                                <div class="entry-content">
                                    <div class="meta-box clearfix">
                                        <?php if ( 1 == $show_date ) : ?>
                                            <span class="entry-date pull-left">
                                                <span class="entry-day"><?php echo esc_html( get_the_date('d') ); ?></span>
                                                <span class="entry-month"><?php echo esc_html( get_the_date('M') ); ?></span>
                                            </span>
                                        <?php endif; ?>
                                        <div class="meta-box-right">
                                            <h6 class="entry-title">
                                                <a href="<?php the_permalink();?>" title="<?php echo esc_attr($post_title); ?>"><?php echo esc_html($post_title); ?></a>
                                            </h6>
                                            <footer>
                                                <?php if ( 1 == $show_category ) : ?>
                                                    <span><?php esc_html_e('Posted in:', 'verado-lite'); ?></span>
                                                    <?php the_category(', ');
                                                endif;
                                                    if ( 1 == $show_comment):
                                                ?>
                                                    <span class="comments">
                                                        <span><?php esc_html_e('With:', 'verado-lite'); ?></span>
                                                        <?php comments_popup_link('0 <i class="fa fa-comments-o"></i>', '1 <i class="fa fa-comments-o"></i>', '% <i class="fa fa-comments-o"></i>');?>
                                                    </span>
                                                <?php endif; ?>
                                            </footer>
                                        </div>
                                    </div>
                                    <?php if ( 1 == $show_exceprt ) : ?>
                                        <p class="entry-excerpt"><?php echo wp_kses_post( $post_excerpt ); ?></p>
                                    <?php endif; ?>
                                    <a href="<?php the_permalink();?>" title="<?php echo esc_attr($post_title); ?>" class="read-more"><?php esc_html_e('Read more', 'verado-lite');?><span><i class="fa fa-long-arrow-right"></i></span></a>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>
                <?php endif; ?>
            </div>
        <?php
		wp_reset_postdata();
		echo $after_widget;
		$content = ob_get_clean();
        echo $content;
	}
}

