<?php
/**
 * Kopa Contact Widget
 *
 * @author 		Kopatheme
 * @category 	Widgets
 * @package 	KopaFramework/Widgets
 * @since    	1.0.0
 * @extends 	Kopa_Widget
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Kopa_Widget_Contact extends Kopa_Widget {

    public $kpb_group = 'others';

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->widget_cssclass    = 'kopa-contact-widget widget_text';
		$this->widget_description = __( 'Show contact info', 'verado-lite' );
		$this->widget_id          = 'kopa-contact-widget';
		$this->widget_name        = __( '(Kopa) Contact', 'verado-lite' );
		$this->settings           = array(
			'title'  => array(
				'type'  => 'text',
				'std'   => __( 'ADDRESS', 'verado-lite' ),
				'label' => __( 'Title', 'verado-lite' )
			),
            'street'  => array(
                'type'  => 'text',
                'std'   => '',
                'label' => __( 'Street', 'verado-lite' )
            ),
            'city'  => array(
                'type'  => 'text',
                'std'   => '',
                'label' => __( 'City', 'verado-lite' )
            ),
			'time_work1'  => array(
				'type'  => 'text',
				'std'   => '',
				'label' => __( 'Time work 1', 'verado-lite' )
			),
            'time_work2'  => array(
                'type'  => 'text',
                'std'   => '',
                'label' => __( 'Time work 2', 'verado-lite' )
            ),
            'map_text'  => array(
                'type'  => 'text',
                'std'   => __( 'View Bigger Map', 'verado-lite' ),
                'label' => __( 'Button text', 'verado-lite' )
            ),
            'map_link'  => array(
                'type'  => 'text',
                'std'   => '',
                'label' => __( 'Button link', 'verado-lite' )
            ),
            'target' => array(
                'type'  => 'checkbox',
                'std'   => 1,
                'label' => __( 'Open link in a new tab', 'verado-lite' )
            )
		);
		parent::__construct();
	}

	/**
	 * widget function.
	 *
	 * @see WP_Widget
	 * @access public
	 * @param array $args
	 * @param array $instance
	 * @return void
	 */
	public function widget( $args, $instance ) {

		ob_start();
		extract( $args );

		$title       = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );

        $instance = wp_parse_args((array)$instance, verado_lite_get_widget_default($this->settings));
        extract ($instance);

		echo $before_widget;

        if ( ! empty($title) ) : ?>
            <h3 class="widget-title"><?php echo esc_html($title); ?></h3>
        <?php endif; ?>

        <?php
            if ( ! empty($street) || ! empty($city) || ! empty($time_work1) || ! empty($time_work2) || ! empty($map_link) ) :
        ?>
            <ul class="widget-content">
                <?php if ( ! empty($street) ) : ?>
                    <li><?php echo esc_html($street); ?></li>
                <?php endif; ?>

                <?php if ( ! empty($city) ) : ?>
                    <li><?php echo esc_html($city); ?></li>
                <?php endif; ?>

                <?php if ( ! empty($time_work1) ) : ?>
                    <li><?php echo esc_html($time_work1); ?></li>
                <?php endif; ?>

                <?php if ( ! empty($time_work2) ) : ?>
                    <li><?php echo esc_html($time_work2); ?></li>
                <?php endif; ?>

                <?php
                    if ( ! empty($map_text) ) {
                        echo '<li>';
                            if ( ! empty($map_link) ) {
                                $target_link = '_self';
                                if ( 1 == $target ) {
                                    $target_link = '_blank';
                                }
                                echo '<a href="' . esc_url($map_link) . '" title="' . esc_attr($map_text) . '" target="' . esc_attr($target_link) . '">';
                            }
                            echo esc_html($map_text);
                            if ( ! empty($map_link) ) {
                                echo '</a>';
                            }
                        echo '</li>';
                    }
                ?>
            </ul>
        <?php endif; ?>

        <?php

		echo $after_widget;

		$content = ob_get_clean();

		echo $content;
	}
}
